@@ -36,6 +36,7 @@ describe 'barbican::api' do
         :rabbit_use_ssl                                => '<SERVICE DEFAULT>',
         :rabbit_heartbeat_timeout_threshold            => '<SERVICE DEFAULT>',
         :rabbit_heartbeat_rate                         => '<SERVICE DEFAULT>',
+        :rabbit_heartbeat_in_pthread                   => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                              => '<SERVICE DEFAULT>',
         :amqp_durable_queues                           => '<SERVICE DEFAULT>',
         :max_allowed_secret_in_bytes                   => '<SERVICE DEFAULT>',
@@ -62,6 +63,7 @@ describe 'barbican::api' do
         :retry_scheduler_periodic_interval_max_seconds => '<SERVICE DEFAULT>',
         :service_name                                  => platform_params[:service_name],
         :enable_proxy_headers_parsing                  => '<SERVICE DEFAULT>',
+        :max_request_body_size                         => '<SERVICE DEFAULT>',
         :multiple_secret_stores_enabled                => false,
         :enabled_secret_stores                         => 'simple_crypto',
       }
@@ -79,6 +81,7 @@ describe 'barbican::api' do
         :rabbit_use_ssl                                => true,
         :rabbit_heartbeat_timeout_threshold            => '10',
         :rabbit_heartbeat_rate                         => '10',
+        :rabbit_heartbeat_in_pthread                   => true,
         :rabbit_ha_queues                              => true,
         :amqp_durable_queues                           => true,
         :enable_queue                                  => true,
@@ -103,6 +106,7 @@ describe 'barbican::api' do
         :max_allowed_secret_in_bytes                   => 20000,
         :max_allowed_request_size_in_bytes             => 2000000,
         :enable_proxy_headers_parsing                  => false,
+        :max_request_body_size                         => '102400',
         :multiple_secret_stores_enabled                => true,
         :enabled_secret_stores                         => 'simple_crypto,dogtag,kmip',
       }
@@ -161,6 +165,7 @@ describe 'barbican::api' do
           is_expected.to contain_barbican_config('oslo_messaging_notifications/topics').with_value(param_hash[:notification_topics])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash[:rabbit_heartbeat_timeout_threshold])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash[:rabbit_heartbeat_rate])
+          is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(param_hash[:rabbit_heartbeat_in_pthread])
           is_expected.to contain_oslo__messaging__rabbit('barbican_config').with(
             :rabbit_use_ssl     => true,
             :kombu_ssl_ca_certs => 'path_to_certs',
@@ -210,6 +215,21 @@ describe 'barbican::api' do
       )}
     end
 
+    describe 'with max_request_body_size' do
+      let :pre_condition do
+        'class { "barbican::keystone::authtoken": password => "secret", }
+        include ::apache'
+      end
+
+      let :params do
+        default_params.merge!({:max_request_body_size => '102400' })
+      end
+
+      it { is_expected.to contain_oslo__middleware('barbican_config').with(
+        :max_request_body_size => '102400',
+      )}
+    end
+
     describe 'with SSL socket options set' do
       let :pre_condition do
           'class { "barbican::keystone::authtoken": password => "secret", }
